@@ -241,7 +241,7 @@ class LiveThread(RedditBase):
 
     @property
     def contrib(self):
-        """An instance of :class:`.LiveThreadContribution`.
+        """Provide an instance of :class:`.LiveThreadContribution`.
 
         Usage:
 
@@ -257,12 +257,12 @@ class LiveThread(RedditBase):
 
     @property
     def contributor(self):
-        """An instance of :class:`.LiveContributorRelationship`.
+        """Provide an instance of :class:`.LiveContributorRelationship`.
 
         You can call the instance to get a list of contributors which is
         represented as :class:`.RedditorList` instance consists of
         :class:`.Redditor` instances. Those Redditor instances have
-        `permissions` attributes as contributors:
+        ``permissions`` attributes as contributors:
 
         .. code-block:: python
 
@@ -525,7 +525,7 @@ class LiveUpdate(RedditBase):
 
     @property
     def contrib(self):
-        """An instance of :class:`.LiveUpdateContribution`.
+        """Provide an instance of :class:`.LiveUpdateContribution`.
 
         Usage:
 
@@ -571,17 +571,19 @@ class LiveUpdate(RedditBase):
            update.author     # raise ``AttributeError``
         """
         if _data is not None:
+            # Since _data (part of JSON returned from reddit) have no
+            # thread ID, self._thread must be set by the caller of
+            # LiveUpdate(). See the code of LiveThread.updates() for example.
             super(LiveUpdate, self).__init__(reddit, _data)
-            self._fetched = True
         elif thread_id and update_id:
             super(LiveUpdate, self).__init__(reddit, None)
             self._thread = LiveThread(self._reddit, thread_id)
             self.id = update_id  # pylint: disable=invalid-name
-            self._fetched = True
-            self._contrib = None
         else:
             raise TypeError('Either `thread_id` and `update_id`, or '
                             '`_data` must be provided.')
+        self._fetched = True
+        self._contrib = None
 
     def __setattr__(self, attribute, value):
         """Objectify author."""
