@@ -157,7 +157,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
     def flair(self):
         """Provide an instance of :class:`.SubredditFlair`.
 
-        Provides the interface for interacting with a subreddit's flair. For
+        Use this attribute for interacting with a subreddit's flair. For
         example to list all the flair for a subreddit which you have the
         ``flair`` moderator permission on try:
 
@@ -166,6 +166,13 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
            for flair in reddit.subreddit('NAME').flair():
                print(flair)
 
+        Flair templates can be interacted with through this attribute via:
+
+        .. code-block:: python
+
+           for template in reddit.subreddit('NAME').flair.templates:
+               print(template)
+
         """
         if self._flair is None:
             self._flair = SubredditFlair(self)
@@ -329,7 +336,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         """
         return self._reddit.get(API_PATH['rules'].format(subreddit=self))
 
-    def search(self, query, sort='relevance', syntax='cloudsearch',
+    def search(self, query, sort='relevance', syntax='lucene',
                time_filter='all', **generator_kwargs):
         """Return a ListingGenerator for items that match ``query``.
 
@@ -337,14 +344,10 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
         :param sort: Can be one of: relevance, hot, top, new,
             comments. (default: relevance).
         :param syntax: Can be one of: cloudsearch, lucene, plain
-            (default: cloudsearch -- will be lucene in PRAW 5).
+            (default: lucene).
         :param time_filter: Can be one of: all, day, hour, month, week, year
             (default: all).
 
-        .. warning:: (Deprecation) The default search syntax is changing to
-           ``lucene`` in PRAW 5. For forward compatibility please explicitly
-           provide the search syntax.
-
         For more information on building a search query see:
             https://www.reddit.com/wiki/search
 
@@ -396,11 +399,12 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
         Submissions are yielded newest first.
 
-        **Example**: If you want to obtain all submissions to ``/r/politics``
-        on November 8, 2016 PST. First you need to determine the start and end
-        dates as UNIX timestamps. Using http://www.epochconverter.com/ those
-        timestamps are 1478592000, and 1478678400 respectively. The following
-        outputs all such submissions' titles.
+        **Example**: Suppose you want to obtain all submissions to
+        ``/r/politics`` on November 8, 2016 PST. First, you need to determine
+        the start and end dates as UNIX timestamps. Using
+        http://www.epochconverter.com/, those timestamps are 1478592000 and
+        1478678400, respectively. The following outputs all such submissions'
+        titles:
 
         .. code:: python
 
@@ -410,6 +414,9 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
         As of this writing there are 809 results.
 
+        .. note:: The results are only as reliable as reddit's search.
+           Submissions may be missing from the results.
+
         """
         utc_offset = 28800
         now = int(time.time())
@@ -427,7 +434,7 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
             current_ids = set()
             found_new_submission = False
             for submission in self.search(query, limit=None, params=params,
-                                          sort='new'):
+                                          sort='new', syntax='cloudsearch'):
                 current_ids.add(submission.id)
                 end = min(end, int(submission.created))
                 if submission.id not in last_ids:
@@ -436,8 +443,8 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
                 params['after'] = submission.fullname
             last_ids = current_ids
 
-    def submit(self, title, selftext=None, url=None, resubmit=True,
-               send_replies=True):
+    def submit(self, title, selftext=None, url=None, flair_id=None,
+               flair_text=None, resubmit=True, send_replies=True):
         """Add a submission to the subreddit.
 
         :param title: The title of the submission.
@@ -445,6 +452,9 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
             submission. Use an empty string, ``''``, to make a title-only
             submission.
         :param url: The URL for a ``link`` submission.
+        :param flair_id: The flair template to select (default: None).
+        :param flair_text: If the template's ``flair_text_editable`` value is
+            True, this value will set a custom text (default: None).
         :param resubmit: When False, an error will occur if the URL has already
             been submitted (default: True).
         :param send_replies: When True, messages will be sent to the submission
@@ -458,8 +468,9 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
         .. code:: python
 
+           title = 'PRAW documentation'
            url = 'https://praw.readthedocs.io'
-           reddit.subreddit('reddit_api_test').submit(url=url)
+           reddit.subreddit('reddit_api_test').submit(title, url=url)
 
         """
         if (bool(selftext) or selftext == '') == bool(url):
@@ -467,6 +478,9 @@ class Subreddit(RedditBase, MessageableMixin, SubredditListingMixin):
 
         data = {'sr': str(self), 'resubmit': bool(resubmit),
                 'sendreplies': bool(send_replies), 'title': title}
+        for key, value in (('flair_id', flair_id), ('flair_text', flair_text)):
+            if value is not None:
+                data[key] = value
         if selftext is not None:
             data.update(kind='self', text=selftext)
         else:
@@ -589,6 +603,42 @@ class SubredditFilters(object):
 class SubredditFlair(object):
     """Provide a set of functions to interact with a Subreddit's flair."""
 
+    @property
+    def link_templates(self):
+        """Provide an instance of :class:`.SubredditLinkFlairTemplates`.
+
+        Use this attribute for interacting with a subreddit's link flair
+        templates. For example to list all the link flair templates for a
+        subreddit which you have the ``flair`` moderator permission on try:
+
+        .. code-block:: python
+
+           for template in reddit.subreddit('NAME').flair.link_templates:
+               print(template)
+
+        """
+        if self._link_templates is None:
+            self._link_templates = SubredditLinkFlairTemplates(self.subreddit)
+        return self._link_templates
+
+    @property
+    def templates(self):
+        """Provide an instance of :class:`.SubredditRedditorFlairTemplates`.
+
+        Use this attribute for interacting with a subreddit's flair
+        templates. For example to list all the flair templates for a subreddit
+        which you have the ``flair`` moderator permission on try:
+
+        .. code-block:: python
+
+           for template in reddit.subreddit('NAME').flair.templates:
+               print(template)
+
+        """
+        if self._templates is None:
+            self._templates = SubredditRedditorFlairTemplates(self.subreddit)
+        return self._templates
+
     def __call__(self, redditor=None, **generator_kwargs):
         """Return a generator for Redditors and their associated flair.
 
@@ -616,22 +666,8 @@ class SubredditFlair(object):
         :param subreddit: The subreddit whose flair to work with.
 
         """
+        self._link_templates = self._templates = None
         self.subreddit = subreddit
-        self.templates = SubredditFlairTemplates(subreddit)
-
-    def __iter__(self):
-        """Iterate through the Redditors and their associated flair.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     iterating over ``subreddit.flair`` instead of
-                     ``subreddit.flair``.
-
-        """
-        url = API_PATH['flairlist'].format(subreddit=self.subreddit)
-        params = {'unique': self.subreddit._reddit._next_unique}
-        for item in ListingGenerator(self.subreddit._reddit, url, None,
-                                     params=params):
-            yield item
 
     def configure(self, position='right', self_assign=False,
                   link_position='left', link_self_assign=False,
@@ -671,8 +707,7 @@ class SubredditFlair(object):
 
         """
         url = API_PATH['deleteflair'].format(subreddit=self.subreddit)
-        # PRAW5 REMOVE (return statement)
-        return self.subreddit._reddit.post(url, data={'name': str(redditor)})
+        self.subreddit._reddit.post(url, data={'name': str(redditor)})
 
     def delete_all(self):
         """Delete all Redditor flair in the Subreddit.
@@ -683,7 +718,7 @@ class SubredditFlair(object):
         """
         return self.update(x['user'] for x in self())
 
-    def set(self, redditor=None, text='', css_class='', thing=None):
+    def set(self, redditor=None, text='', css_class=''):
         """Set flair for a Redditor.
 
         :param redditor: (Required) A redditor name (e.g., ``'spez'``) or
@@ -696,13 +731,6 @@ class SubredditFlair(object):
         This method can only be used by an authenticated user who is a
         moderator of the associated Subreddit.
 
-        .. warning:: The use of this method to set the flair of a
-                     :class:`.Submission` is deprecated and will be removed in
-                     PRAW 5. Use :meth:`.flair` instead.
-
-        .. warning:: The use of the keyword argument ``thing`` is deprecated
-                     and will be removed in PRAW 5. Use ``redditor`` instead.
-
         Example:
 
         .. code:: python
@@ -710,17 +738,7 @@ class SubredditFlair(object):
            reddit.subreddit('redditdev').flair.set('bboe', 'PRAW author')
 
         """
-        # PRAW5 REMOVE
-        if bool(redditor) == bool(thing):
-            raise TypeError('`redditor` must be provided.')
-        if redditor is None:
-            redditor = thing
-
-        data = {'css_class': css_class, 'text': text}
-        if redditor.__class__.__name__ == 'Submission':  # PRAW5 REMOVE
-            data['link'] = redditor.fullname
-        else:
-            data['name'] = str(redditor)
+        data = {'css_class': css_class, 'name': str(redditor), 'text': text}
         url = API_PATH['flair'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(url, data=data)
 
@@ -743,8 +761,8 @@ class SubredditFlair(object):
         :returns: List of dictionaries indicating the success or failure of
             each update.
 
-        For example to clear the flair text, and set the `praw` flair css class
-        on a few users try:
+        For example to clear the flair text, and set the ``praw`` flair css
+        class on a few users try:
 
         .. code:: python
 
@@ -783,45 +801,36 @@ class SubredditFlairTemplates(object):
 
         :param subreddit: The subreddit whose flair templates to work with.
 
+        .. note:: This class should not be initialized directly. Instead obtain
+           an instance via:
+           ``reddit.subreddit('subreddit_name').flair.templates`` or
+           ``reddit.subreddit('subreddit_name').flair.link_templates``.
+
         """
         self.subreddit = subreddit
 
-    def __iter__(self):
-        """Iterate through the user flair templates."""
-        url = API_PATH['flairselector'].format(subreddit=self.subreddit)
-        data = {'unique': self.subreddit._reddit._next_unique}
-        for template in self.subreddit._reddit.post(url, data=data)['choices']:
-            yield template
-
-    def add(self, text, css_class='', text_editable=False, is_link=False):
-        """Add a flair template to the associated subreddit.
-
-        :param text: The flair template's text (required).
-        :param css_class: The flair template's css_class (default: '').
-        :param text_editable: (boolean) Indicate if the flair text can be
-            modified for each Redditor that sets it (default: False).
-        :param is_link: (boolean) When True, add a link flair template rather
-            than a Redditor flair template (default: False).
-
-        """
+    def _add(self, text, css_class='', text_editable=False, is_link=None):
         url = API_PATH['flairtemplate'].format(subreddit=self.subreddit)
         data = {'css_class': css_class, 'flair_type': self.flair_type(is_link),
                 'text': text, 'text_editable': bool(text_editable)}
         self.subreddit._reddit.post(url, data=data)
 
-    def clear(self, is_link=False):
-        """Remove all flair templates from the subreddit.
-
-        :param is_link: (boolean) When True, clear all link flair templates
-            rather than a Redditor flair templates (default: False).
-
-        """
+    def _clear(self, is_link=None):
         url = API_PATH['flairtemplateclear'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(
             url, data={'flair_type': self.flair_type(is_link)})
 
     def delete(self, template_id):
-        """Remove a flair template provided by ``template_id``."""
+        """Remove a flair template provided by ``template_id``.
+
+        For example, to delete the first Redditor flair template listed, try:
+
+        .. code-block:: python
+
+           template_info = list(subreddit.flair.templates)[0]
+           subreddit.flair.templates.delete(template_info['flair_template_id])
+
+        """
         url = API_PATH['flairtemplatedelete'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(
             url, data={'flair_template_id': template_id})
@@ -835,6 +844,15 @@ class SubredditFlairTemplates(object):
         :param text_editable: (boolean) Indicate if the flair text can be
             modified for each Redditor that sets it (default: False).
 
+        For example to make a link flair template text_editable, try:
+
+        .. code-block:: python
+
+           template_info = list(subreddit.flair.templates)[0]
+           subreddit.flair.templates.update(
+               template_info['flair_template_id'],
+               text_editable=True)
+
         """
         url = API_PATH['flairtemplate'].format(subreddit=self.subreddit)
         data = {'css_class': css_class, 'flair_template_id': template_id,
@@ -842,6 +860,109 @@ class SubredditFlairTemplates(object):
         self.subreddit._reddit.post(url, data=data)
 
 
+class SubredditRedditorFlairTemplates(SubredditFlairTemplates):
+    """Provide functions to interact with Redditor flair templates."""
+
+    def __iter__(self):
+        """Iterate through the user flair templates.
+
+        Example:
+
+        .. code-block:: python
+
+           for template in reddit.subreddit('NAME').flair.templates:
+               print(template)
+
+
+        """
+        url = API_PATH['flairselector'].format(subreddit=self.subreddit)
+        data = {'unique': self.subreddit._reddit._next_unique}
+        for template in self.subreddit._reddit.post(url, data=data)['choices']:
+            yield template
+
+    def add(self, text, css_class='', text_editable=False):
+        """Add a Redditor flair template to the associated subreddit.
+
+        :param text: The flair template's text (required).
+        :param css_class: The flair template's css_class (default: '').
+        :param text_editable: (boolean) Indicate if the flair text can be
+            modified for each Redditor that sets it (default: False).
+
+        For example, to add an editable Redditor flair try:
+
+        .. code-block:: python
+
+           reddit.subreddit('NAME').flair.templates.add(
+               css_class='praw', text_editable=True)
+
+        """
+        self._add(text, css_class=css_class, text_editable=text_editable,
+                  is_link=False)
+
+    def clear(self):
+        """Remove all Redditor flair templates from the subreddit.
+
+        For example:
+
+        .. code-block:: python
+
+           reddit.subreddit('NAME').flair.templates.clear()
+
+        """
+        self._clear(is_link=False)
+
+
+class SubredditLinkFlairTemplates(SubredditFlairTemplates):
+    """Provide functions to interact with link flair templates."""
+
+    def __iter__(self):
+        """Iterate through the link flair templates.
+
+        Example:
+
+        .. code-block:: python
+
+           for template in reddit.subreddit('NAME').flair.link_templates:
+               print(template)
+
+
+        """
+        url = API_PATH['link_flair'].format(subreddit=self.subreddit)
+        for template in self.subreddit._reddit.get(url):
+            yield template
+
+    def add(self, text, css_class='', text_editable=False):
+        """Add a link flair template to the associated subreddit.
+
+        :param text: The flair template's text (required).
+        :param css_class: The flair template's css_class (default: '').
+        :param text_editable: (boolean) Indicate if the flair text can be
+            modified for each Redditor that sets it (default: False).
+
+        For example, to add an editable link flair try:
+
+        .. code-block:: python
+
+           reddit.subreddit('NAME').flair.link_templates.add(
+               css_class='praw', text_editable=True)
+
+        """
+        self._add(text, css_class=css_class, text_editable=text_editable,
+                  is_link=True)
+
+    def clear(self):
+        """Remove all link flair templates from the subreddit.
+
+        For example:
+
+        .. code-block:: python
+
+           reddit.subreddit('NAME').flair.link_templates.clear()
+
+        """
+        self._clear(is_link=True)
+
+
 class SubredditModeration(object):
     """Provides a set of moderation functions to a Subreddit."""
 
@@ -866,33 +987,11 @@ class SubredditModeration(object):
         url = API_PATH['accept_mod_invite'].format(subreddit=self.subreddit)
         self.subreddit._reddit.post(url)
 
-    @staticmethod
-    def approve(thing):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.approve()``,
-                     ``submission.mod.approve()``.
-
-        """
-        thing.mod.approve()
-
-    @staticmethod
-    def distinguish(thing, how='yes', sticky=False):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.distinguish()``,
-                     ``submission.mod.distinguish()``.
-
-        """
-        thing.mod.distinguish(how=how, sticky=sticky)
-
     def edited(self, only=None, **generator_kwargs):
         """Return a ListingGenerator for edited comments and submissions.
 
-        :param only: If specified, one of `comments`, or 'submissions' to yield
-            only results of that type.
+        :param only: If specified, one of ``'comments'``, or ``'submissions'``
+            to yield only results of that type.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -910,17 +1009,6 @@ class SubredditModeration(object):
             self.subreddit._reddit, API_PATH['about_edited'].format(
                 subreddit=self.subreddit), **generator_kwargs)
 
-    @staticmethod
-    def ignore_reports(thing):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.ignore_reports()``,
-                     ``submission.mod.ignore_reports()``.
-
-        """
-        thing.mod.ignore_reports()
-
     def inbox(self, **generator_kwargs):
         """Return a ListingGenerator for moderator messages.
 
@@ -969,8 +1057,8 @@ class SubredditModeration(object):
     def modqueue(self, only=None, **generator_kwargs):
         """Return a ListingGenerator for comments/submissions in the modqueue.
 
-        :param only: If specified, one of `comments`, or 'submissions' to yield
-            only results of that type.
+        :param only: If specified, one of ``'comments'``, or ``'submissions'``
+            to yield only results of that type.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -988,22 +1076,11 @@ class SubredditModeration(object):
             self.subreddit._reddit, API_PATH['about_modqueue'].format(
                 subreddit=self.subreddit), **generator_kwargs)
 
-    @staticmethod
-    def remove(thing, spam=False):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.remove()``,
-                     ``submission.mod.remove()``.
-
-        """
-        thing.mod.remove(spam=spam)
-
     def reports(self, only=None, **generator_kwargs):
         """Return a ListingGenerator for reported comments and submissions.
 
-        :param only: If specified, one of `comments`, or 'submissions' to yield
-            only results of that type.
+        :param only: If specified, one of ``'comments'``, or ``'submissions'``
+            to yield only results of that type.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -1030,8 +1107,8 @@ class SubredditModeration(object):
     def spam(self, only=None, **generator_kwargs):
         """Return a ListingGenerator for spam comments and submissions.
 
-        :param only: If specified, one of `comments`, or 'submissions' to yield
-            only results of that type.
+        :param only: If specified, one of ``'comments'``, or ``'submissions'``
+            to yield only results of that type.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -1049,28 +1126,6 @@ class SubredditModeration(object):
             self.subreddit._reddit, API_PATH['about_spam'].format(
                 subreddit=self.subreddit), **generator_kwargs)
 
-    @staticmethod
-    def undistinguish(thing):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.undistinguish()``,
-                     ``submission.mod.undistinguish()``.
-
-        """
-        thing.mod.undistinguish()
-
-    @staticmethod
-    def unignore_reports(thing):
-        """DEPRECATED.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``comment.mod.unignore_reports()``,
-                     ``submission.mod.unignore_reports()``.
-
-        """
-        thing.mod.unignore_reports()
-
     def unmoderated(self, **generator_kwargs):
         """Return a ListingGenerator for unmoderated submissions.
 
@@ -1128,8 +1183,8 @@ class SubredditModeration(object):
         :param header_hover_text: The text seen when hovering over the snoo.
         :param hide_ads: Don't show ads within this subreddit. Only applies to
             gold-user only subreddits.
-        :param key_color: A 6-digit rgb hex color (e.g. `#AABBCC`), used as a
-            thematic color for your subreddit on mobile.
+        :param key_color: A 6-digit rgb hex color (e.g. ``'#AABBCC'``), used as
+            a thematic color for your subreddit on mobile.
         :param lang: A valid IETF language tag (underscore separated).
         :param link_type: The types of submissions users can make.
             One of ``any``, ``link``, ``self``.
@@ -1294,20 +1349,6 @@ class SubredditRelationship(object):
         self.relationship = relationship
         self.subreddit = subreddit
 
-    def __iter__(self):
-        """Iterate through the Redditors belonging to this relationship.
-
-        .. warning:: (Deprecated) This method will be removed in PRAW 5. Prefer
-                     calling ``subreddit.banned(limit=None)`` instead of
-                     ``subreddit.banned`` and similar for other relationships.
-
-        """
-        url = API_PATH['list_{}'.format(self.relationship)].format(
-            subreddit=self.subreddit)
-        params = {'unique': self.subreddit._reddit._next_unique}
-        for item in self.subreddit._reddit.get(url, params=params):
-            yield item
-
     def add(self, redditor, **other_settings):
         """Add ``redditor`` to this relationship.
 
@@ -1408,10 +1449,10 @@ class ModeratorRelationship(SubredditRelationship):
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
-        :param permissions: When provided (not `None`), permissions should be a
-            list of strings specifying which subset of permissions to grant. An
-            empty list `[]` indicates no permissions, and when not provided
-            `None`, indicates full permissions.
+        :param permissions: When provided (not ``None``), permissions should be
+            a list of strings specifying which subset of permissions to
+            grant. An empty list ``[]`` indicates no permissions, and when not
+            provided ``None``, indicates full permissions.
 
         An invite will be sent unless the user making this call is an admin
         user.
@@ -1432,10 +1473,10 @@ class ModeratorRelationship(SubredditRelationship):
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
-        :param permissions: When provided (not `None`), permissions should be a
-            list of strings specifying which subset of permissions to grant. An
-            empty list `[]` indicates no permissions, and when not provided
-            `None`, indicates full permissions.
+        :param permissions: When provided (not ``None``), permissions should be
+            a list of strings specifying which subset of permissions to
+            grant. An empty list ``[]`` indicates no permissions, and when not
+            provided ``None``, indicates full permissions.
 
         For example, to invite ``'spez'`` with ``'posts'`` and ``'mail'``
             permissions to ``'/r/test/``, try:
@@ -1485,10 +1526,10 @@ class ModeratorRelationship(SubredditRelationship):
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
-        :param permissions: When provided (not `None`), permissions should be a
-            list of strings specifying which subset of permissions to grant. An
-            empty list `[]` indicates no permissions, and when not provided,
-            `None`, indicates full permissions.
+        :param permissions: When provided (not ``None``), permissions should be
+            a list of strings specifying which subset of permissions to
+            grant. An empty list ``[]`` indicates no permissions, and when not
+            provided, ``None``, indicates full permissions.
 
         For example, to add all permissions to the moderator, try:
 
@@ -1513,10 +1554,10 @@ class ModeratorRelationship(SubredditRelationship):
 
         :param redditor: A redditor name (e.g., ``'spez'``) or
             :class:`~.Redditor` instance.
-        :param permissions: When provided (not `None`), permissions should be a
-            list of strings specifying which subset of permissions to grant. An
-            empty list `[]` indicates no permissions, and when not provided,
-            `None`, indicates full permissions.
+        :param permissions: When provided (not ``None``), permissions should be
+            a list of strings specifying which subset of permissions to
+            grant. An empty list ``[]`` indicates no permissions, and when not
+            provided, ``None``, indicates full permissions.
 
         For example, to grant the flair and mail permissions to the moderator
         invite, try:
@@ -1548,6 +1589,37 @@ class Modmail(object):
 
            reddit.subreddit('redditdev').modmail('2gmz', mark_read=True)
 
+        To print all messages from a conversation as Markdown source:
+
+        .. code:: python
+
+           conversation = reddit.subreddit('redditdev').modmail('2gmz',
+                                                                mark_read=True)
+           for message in conversation.messages:
+               print(message.body_markdown)
+
+        ``ModmailConversation.user`` is a special instance of
+        :class:`.Redditor` with extra attributes describing the non-moderator
+        user's recent posts, comments, and modmail messages within the
+        subreddit, as well as information on active bans and mutes. This
+        attribute does not exist on internal moderator discussions.
+
+        For example, to print the user's ban status:
+
+        .. code:: python
+
+           conversation = reddit.subreddit('redditdev').modmail('2gmz',
+                                                                mark_read=True)
+           print(conversation.user.ban_status)
+
+        To print a list of recent submissions by the user:
+
+        .. code:: python
+
+           conversation = reddit.subreddit('redditdev').modmail('2gmz',
+                                                                mark_read=True)
+           print(conversation.user.recent_posts)
+
         """
         # pylint: disable=invalid-name,redefined-builtin
         return ModmailConversation(self.subreddit._reddit, id=id,
@@ -1569,10 +1641,11 @@ class Modmail(object):
         this method. Instead, use :meth:`~.Modmail.subreddits` to get a list of
         subreddits using the new modmail.
 
-        :param other_subreddits: A list of `.Subreddit` instances for which to
-            mark conversations (default: None).
+        :param other_subreddits: A list of :class:`.Subreddit` instances for
+            which to mark conversations (default: None).
         :param state: Can be one of: all, archived, highlighted, inprogress,
-            mod, new, notifications, (default: all).
+            mod, new, notifications, (default: all). "all" does not include
+            internal or archived conversations.
         :returns: A list of :class:`.ModmailConversation` instances that were
             marked read.
 
@@ -1601,12 +1674,14 @@ class Modmail(object):
         :param limit: The maximum number of conversations to fetch. If None,
             the server-side default is 25 at the time of writing
             (default: None).
-        :param other_subreddits: A list of `.Subreddit` instances for which to
-            fetch conversations (default: None).
+        :param other_subreddits: A list of :class:`.Subreddit` instances for
+            which to fetch conversations (default: None).
         :param sort: Can be one of: mod, recent, unread, user
             (default: recent).
         :param state: Can be one of: all, archived, highlighted, inprogress,
-            mod, new, notifications, (default: all).
+            mod, new, notifications, (default: all). "all" does not include
+            internal or archived conversations.
+
 
         Example:
 
@@ -1641,7 +1716,7 @@ class Modmail(object):
             :class:`.Redditor`.
         :param author_hidden: When True, author is hidden from non-moderators
             (default: False).
-        :returns: A `.ModmailConversation` object for the newly created
+        :returns: A :class:`.ModmailConversation` object for the newly created
             conversation.
 
         .. code:: python
